@@ -4,6 +4,7 @@ __all__ = [
     "LazyConversion",
     "as_names",
     "as_str",
+    "catch_value_error",
     "dataclass_input_wrapper",
     "deserializer",
     "reset_deserializers",
@@ -18,6 +19,7 @@ from .conversions import AnyConversion, Conversion, LazyConversion
 from .converters import (
     as_names,
     as_str,
+    catch_value_error,
     deserializer,
     reset_deserializers,
     reset_serializer,
