@@ -1,4 +1,4 @@
-from inspect import Parameter, isclass, signature
+from inspect import Parameter, signature
 from typing import Any, Callable, Dict, Generic, Optional, Tuple, Type, cast
 
 from apischema.types import AnyType
@@ -17,9 +17,9 @@ Converter = Callable[[Any], Any]
 
 def converter_types(
     converter: Converter,
-    source: Optional[AnyType] = None,
-    target: Optional[AnyType] = None,
-    namespace: Dict[str, Any] = None,
+    source: AnyType = None,
+    target: AnyType = None,
+    namespace: Optional[Dict[str, Any]] = None,
 ) -> Tuple[AnyType, AnyType]:
     try:
         # in pre 3.9, Generic __new__ perturb signature of types
@@ -32,7 +32,7 @@ def converter_types(
         else:
             parameters = list(signature(converter).parameters.values())
     except ValueError:  # builtin types
-        if target is None and isclass(converter):
+        if target is None and is_type(converter):
             target = cast(Type[Any], converter)
         if source is None:
             raise TypeError("Converter source is unknown") from None
@@ -51,7 +51,7 @@ def converter_types(
         if source is not None and target is not None:
             return source, target
         types = get_type_hints(converter, None, namespace, include_extras=True)
-        if not types and isclass(converter):
+        if not types and is_type(converter):
             types = get_type_hints(
                 converter.__new__, None, namespace, include_extras=True
             ) or get_type_hints(
@@ -63,12 +63,12 @@ def converter_types(
             except KeyError:
                 raise TypeError("converter source is unknown") from None
         if target is None:
-            try:
-                target = types.pop("return")
-            except KeyError:
-                if isclass(converter):
-                    target = cast(Type, converter)
-                else:
+            if is_type(converter):
+                target = cast(Type, converter)
+            else:
+                try:
+                    target = types.pop("return")
+                except KeyError:
                     raise TypeError("converter target is unknown") from None
     return source, target
 
