@@ -4,14 +4,14 @@ from dataclasses import *
 
 def _replace(__obj, **changes):
     from dataclasses import _FIELD_INITVAR, _FIELDS
-    from dataclasses import replace as replace_  # type: ignore
+    from dataclasses import replace as replace_
 
     from apischema.fields import FIELDS_SET_ATTR, fields_set, set_fields
 
     # Fix https://bugs.python.org/issue36470
     assert is_dataclass(__obj)
     for name, field in getattr(__obj, _FIELDS).items():
-        if field._field_type == _FIELD_INITVAR and name not in changes:  # type: ignore
+        if field._field_type == _FIELD_INITVAR and name not in changes:
             if field.default is not MISSING:
                 changes[name] = field.default
             elif field.default_factory is not MISSING:
