@@ -58,6 +58,7 @@ from apischema.deserialization.methods import (
     FieldsConstructor,
     FlattenedField,
     FloatMethod,
+    FrozenSetMethod,
     IntMethod,
     ListCheckOnlyMethod,
     ListMethod,
@@ -360,13 +361,19 @@ class DeserializationMethodVisitor(
             value_method = value_factory.method
             list_constraints = constraints_validators(constraints)[list]
             method: DeserializationMethod
-            if issubclass(cls, collections.abc.Set):
+            if issubclass(cls, collections.abc.Set) and not issubclass(cls, frozenset):
                 return SetMethod(list_constraints, value_method)
-            elif self.no_copy and check_only(value_method):
+
+            if self.no_copy and check_only(value_method):
                 method = ListCheckOnlyMethod(list_constraints, value_method)
             else:
                 method = ListMethod(list_constraints, value_method)
-            return VariadicTupleMethod(method) if isinstance(cls, tuple) else method
+
+            if issubclass(cls, tuple):
+                return VariadicTupleMethod(method)
+            if issubclass(cls, frozenset):
+                return FrozenSetMethod(method)
+            return method
 
         return self._factory(factory, list)
 
@@ -597,14 +604,9 @@ class DeserializationMethodVisitor(
         def factory(
             constraints: Optional[Constraints], validators: Sequence[Validator]
         ) -> DeserializationMethod:
-            method = SubprimitiveMethod(
-                cls, primitive_factory.merge(constraints, validators).method
-            )
-            if self.pass_through_type(cls):
-                return TypeCheckMethod(cls, method)
-            return method
+            return SubprimitiveMethod(cls, primitive_factory.merge(constraints).method)
 
-        return dataclasses.replace(primitive_factory, factory=factory)
+        return self._factory(factory)
 
     def tuple(self, types: Sequence[AnyType]) -> DeserializationMethodFactory:
         elt_factories = [self.visit(tp) for tp in types]
@@ -752,15 +754,15 @@ def deserialization_method_factory(
 def deserialization_method(
     type: Type[T],
     *,
-    additional_properties: bool = None,
-    aliaser: Aliaser = None,
-    coerce: Coerce = None,
-    conversion: AnyConversion = None,
-    default_conversion: DefaultConversion = None,
-    fall_back_on_default: bool = None,
-    no_copy: bool = None,
-    pass_through: CollectionOrPredicate[type] = None,
-    schema: Schema = None,
+    additional_properties: Optional[bool] = None,
+    aliaser: Optional[Aliaser] = None,
+    coerce: Optional[Coerce] = None,
+    conversion: Optional[AnyConversion] = None,
+    default_conversion: Optional[DefaultConversion] = None,
+    fall_back_on_default: Optional[bool] = None,
+    no_copy: Optional[bool] = None,
+    pass_through: Optional[CollectionOrPredicate[type]] = None,
+    schema: Optional[Schema] = None,
     validators: Collection[Callable] = ()
 ) -> Callable[[Any], T]:
     ...
@@ -770,15 +772,15 @@ def deserialization_method(
 def deserialization_method(
     type: AnyType,
     *,
-    additional_properties: bool = None,
-    aliaser: Aliaser = None,
-    coerce: Coerce = None,
-    conversion: AnyConversion = None,
-    default_conversion: DefaultConversion = None,
-    fall_back_on_default: bool = None,
-    no_copy: bool = None,
-    pass_through: CollectionOrPredicate[type] = None,
-    schema: Schema = None,
+    additional_properties: Optional[bool] = None,
+    aliaser: Optional[Aliaser] = None,
+    coerce: Optional[Coerce] = None,
+    conversion: Optional[AnyConversion] = None,
+    default_conversion: Optional[DefaultConversion] = None,
+    fall_back_on_default: Optional[bool] = None,
+    no_copy: Optional[bool] = None,
+    pass_through: Optional[CollectionOrPredicate[type]] = None,
+    schema: Optional[Schema] = None,
     validators: Collection[Callable] = ()
 ) -> Callable[[Any], Any]:
     ...
@@ -787,15 +789,15 @@ def deserialization_method(
 def deserialization_method(
     type: AnyType,
     *,
-    additional_properties: bool = None,
-    aliaser: Aliaser = None,
-    coerce: Coerce = None,
-    conversion: AnyConversion = None,
-    default_conversion: DefaultConversion = None,
-    fall_back_on_default: bool = None,
-    no_copy: bool = None,
-    pass_through: CollectionOrPredicate[type] = None,
-    schema: Schema = None,
+    additional_properties: Optional[bool] = None,
+    aliaser: Optional[Aliaser] = None,
+    coerce: Optional[Coerce] = None,
+    conversion: Optional[AnyConversion] = None,
+    default_conversion: Optional[DefaultConversion] = None,
+    fall_back_on_default: Optional[bool] = None,
+    no_copy: Optional[bool] = None,
+    pass_through: Optional[CollectionOrPredicate[type]] = None,
+    schema: Optional[Schema] = None,
     validators: Collection[Callable] = ()
 ) -> Callable[[Any], Any]:
     from apischema import settings
@@ -831,15 +833,15 @@ def deserialize(
     type: Type[T],
     data: Any,
     *,
-    additional_properties: bool = None,
-    aliaser: Aliaser = None,
-    coerce: Coerce = None,
-    conversion: AnyConversion = None,
-    default_conversion: DefaultConversion = None,
-    fall_back_on_default: bool = None,
-    no_copy: bool = None,
-    pass_through: CollectionOrPredicate[type] = None,
-    schema: Schema = None,
+    additional_properties: Optional[bool] = None,
+    aliaser: Optional[Aliaser] = None,
+    coerce: Optional[Coerce] = None,
+    conversion: Optional[AnyConversion] = None,
+    default_conversion: Optional[DefaultConversion] = None,
+    fall_back_on_default: Optional[bool] = None,
+    no_copy: Optional[bool] = None,
+    pass_through: Optional[CollectionOrPredicate[type]] = None,
+    schema: Optional[Schema] = None,
     validators: Collection[Callable] = ()
 ) -> T:
     ...
@@ -850,15 +852,15 @@ def deserialize(
     type: AnyType,
     data: Any,
     *,
-    additional_properties: bool = None,
-    aliaser: Aliaser = None,
-    coerce: Coerce = None,
-    conversion: AnyConversion = None,
-    default_conversion: DefaultConversion = None,
-    fall_back_on_default: bool = None,
-    no_copy: bool = None,
-    pass_through: CollectionOrPredicate[type] = None,
-    schema: Schema = None,
+    additional_properties: Optional[bool] = None,
+    aliaser: Optional[Aliaser] = None,
+    coerce: Optional[Coerce] = None,
+    conversion: Optional[AnyConversion] = None,
+    default_conversion: Optional[DefaultConversion] = None,
+    fall_back_on_default: Optional[bool] = None,
+    no_copy: Optional[bool] = None,
+    pass_through: Optional[CollectionOrPredicate[type]] = None,
+    schema: Optional[Schema] = None,
     validators: Collection[Callable] = ()
 ) -> Any:
     ...
@@ -875,15 +877,15 @@ def deserialize(
     type: AnyType,
     data: Any,
     *,
-    additional_properties: bool = None,
-    aliaser: Aliaser = None,
-    coerce: Coerce = None,
-    conversion: AnyConversion = None,
-    default_conversion: DefaultConversion = None,
-    fall_back_on_default: bool = None,
-    no_copy: bool = None,
-    pass_through: CollectionOrPredicate[type] = None,
-    schema: Schema = None,
+    additional_properties: Optional[bool] = None,
+    aliaser: Optional[Aliaser] = None,
+    coerce: Optional[Coerce] = None,
+    conversion: Optional[AnyConversion] = None,
+    default_conversion: Optional[DefaultConversion] = None,
+    fall_back_on_default: Optional[bool] = None,
+    no_copy: Optional[bool] = None,
+    pass_through: Optional[CollectionOrPredicate[type]] = None,
+    schema: Optional[Schema] = None,
     validators: Collection[Callable] = ()
 ) -> Any:
     return deserialization_method(
