@@ -623,14 +623,14 @@ def _schema(
 def deserialization_schema(
     tp: AnyType,
     *,
-    additional_properties: bool = None,
-    aliaser: Aliaser = None,
-    all_refs: bool = None,
-    conversion: AnyConversion = None,
-    default_conversion: DefaultConversion = None,
-    ref_factory: RefFactory = None,
-    schema: Schema = None,
-    version: JsonSchemaVersion = None,
+    additional_properties: Optional[bool] = None,
+    aliaser: Optional[Aliaser] = None,
+    all_refs: Optional[bool] = None,
+    conversion: Optional[AnyConversion] = None,
+    default_conversion: Optional[DefaultConversion] = None,
+    ref_factory: Optional[RefFactory] = None,
+    schema: Optional[Schema] = None,
+    version: Optional[JsonSchemaVersion] = None,
     with_schema: bool = True,
 ) -> Mapping[str, Any]:
     from apischema import settings
@@ -654,14 +654,14 @@ def deserialization_schema(
 def serialization_schema(
     tp: AnyType,
     *,
-    additional_properties: bool = None,
-    all_refs: bool = None,
-    aliaser: Aliaser = None,
-    conversion: AnyConversion = None,
-    default_conversion: DefaultConversion = None,
-    ref_factory: RefFactory = None,
-    schema: Schema = None,
-    version: JsonSchemaVersion = None,
+    additional_properties: Optional[bool] = None,
+    all_refs: Optional[bool] = None,
+    aliaser: Optional[Aliaser] = None,
+    conversion: Optional[AnyConversion] = None,
+    default_conversion: Optional[DefaultConversion] = None,
+    ref_factory: Optional[RefFactory] = None,
+    schema: Optional[Schema] = None,
+    version: Optional[JsonSchemaVersion] = None,
     with_schema: bool = True,
 ) -> Mapping[str, Any]:
     from apischema import settings
@@ -752,13 +752,13 @@ def definitions_schema(
     *,
     deserialization: TypesWithConversion = (),
     serialization: TypesWithConversion = (),
-    default_deserialization: DefaultConversion = None,
-    default_serialization: DefaultConversion = None,
-    aliaser: Aliaser = None,
-    version: JsonSchemaVersion = None,
+    default_deserialization: Optional[DefaultConversion] = None,
+    default_serialization: Optional[DefaultConversion] = None,
+    aliaser: Optional[Aliaser] = None,
+    version: Optional[JsonSchemaVersion] = None,
     ref_factory: Optional[RefFactory] = None,
-    all_refs: bool = None,
-    additional_properties: bool = None,
+    all_refs: Optional[bool] = None,
+    additional_properties: Optional[bool] = None,
 ) -> Mapping[str, Mapping[str, Any]]:
     from apischema import settings
 
