@@ -7,6 +7,7 @@ from typing import (
     Collection,
     Dict,
     Mapping,
+    Optional,
     Pattern,
     Sequence,
     Type,
@@ -103,31 +104,31 @@ def json_schema(
     default: Any = Undefined,
     dependentRequired: Mapping[str, Collection[str]] = {},
     deprecated: bool = False,
-    description: str = None,
+    description: Optional[str] = None,
     enum: Sequence[Any] = [],
-    exclusiveMaximum: Number = None,
-    exclusiveMinimum: Number = None,
-    examples: Sequence[Any] = None,
-    format: str = None,
+    exclusiveMaximum: Optional[Number] = None,
+    exclusiveMinimum: Optional[Number] = None,
+    examples: Optional[Sequence[Any]] = None,
+    format: Optional[str] = None,
     items: Union[bool, JsonSchema] = True,
-    maximum: Number = None,
-    minimum: Number = None,
-    maxItems: int = None,
-    minItems: int = None,
-    maxLength: int = None,
-    minLength: int = None,
-    maxProperties: int = None,
-    minProperties: int = None,
-    multipleOf: Number = None,
+    maximum: Optional[Number] = None,
+    minimum: Optional[Number] = None,
+    maxItems: Optional[int] = None,
+    minItems: Optional[int] = None,
+    maxLength: Optional[int] = None,
+    minLength: Optional[int] = None,
+    maxProperties: Optional[int] = None,
+    minProperties: Optional[int] = None,
+    multipleOf: Optional[Number] = None,
     oneOf: Sequence[JsonSchema] = [],
-    pattern: Pattern = None,
+    pattern: Optional[Pattern] = None,
     patternProperties: Mapping[Pattern, JsonSchema] = {},
     prefixItems: Sequence[JsonSchema] = [],
     properties: Mapping[str, JsonSchema] = {},
     readOnly: bool = False,
     required: Sequence[str] = [],
-    title: str = None,
-    type: Union[JsonType, Sequence[JsonType]] = None,
+    title: Optional[str] = None,
+    type: Optional[Union[JsonType, Sequence[JsonType]]] = None,
     uniqueItems: bool = False,
     unevaluatedProperties: Union[bool, JsonSchema] = True,
     writeOnly: bool = False,
