@@ -563,17 +563,17 @@ def serialization_method_factory(
 def serialization_method(
     type: AnyType,
     *,
-    additional_properties: bool = None,
-    aliaser: Aliaser = None,
-    check_type: bool = None,
-    conversion: AnyConversion = None,
-    default_conversion: DefaultConversion = None,
-    exclude_defaults: bool = None,
-    exclude_none: bool = None,
-    exclude_unset: bool = None,
-    fall_back_on_any: bool = None,
-    no_copy: bool = None,
-    pass_through: PassThroughOptions = None,
+    additional_properties: Optional[bool] = None,
+    aliaser: Optional[Aliaser] = None,
+    check_type: Optional[bool] = None,
+    conversion: Optional[AnyConversion] = None,
+    default_conversion: Optional[DefaultConversion] = None,
+    exclude_defaults: Optional[bool] = None,
+    exclude_none: Optional[bool] = None,
+    exclude_unset: Optional[bool] = None,
+    fall_back_on_any: Optional[bool] = None,
+    no_copy: Optional[bool] = None,
+    pass_through: Optional[PassThroughOptions] = None,
 ) -> Callable[[Any], Any]:
     from apischema import settings
 
@@ -601,17 +601,17 @@ def serialize(
     type: AnyType,
     obj: Any,
     *,
-    additional_properties: bool = None,
-    aliaser: Aliaser = None,
-    check_type: bool = None,
-    conversion: AnyConversion = None,
-    default_conversion: DefaultConversion = None,
-    exclude_defaults: bool = None,
-    exclude_none: bool = None,
-    exclude_unset: bool = None,
-    fall_back_on_any: bool = None,
-    no_copy: bool = None,
-    pass_through: PassThroughOptions = None,
+    additional_properties: Optional[bool] = None,
+    aliaser: Optional[Aliaser] = None,
+    check_type: Optional[bool] = None,
+    conversion: Optional[AnyConversion] = None,
+    default_conversion: Optional[DefaultConversion] = None,
+    exclude_defaults: Optional[bool] = None,
+    exclude_none: Optional[bool] = None,
+    exclude_unset: Optional[bool] = None,
+    fall_back_on_any: Optional[bool] = None,
+    no_copy: Optional[bool] = None,
+    pass_through: Optional[PassThroughOptions] = None,
 ) -> Any:
     ...
 
@@ -620,17 +620,17 @@ def serialize(
 def serialize(
     obj: Any,
     *,
-    additional_properties: bool = None,
-    aliaser: Aliaser = None,
-    check_type: bool = None,
-    conversion: AnyConversion = None,
-    default_conversion: DefaultConversion = None,
-    exclude_defaults: bool = None,
-    exclude_none: bool = None,
-    exclude_unset: bool = None,
+    additional_properties: Optional[bool] = None,
+    aliaser: Optional[Aliaser] = None,
+    check_type: Optional[bool] = None,
+    conversion: Optional[AnyConversion] = None,
+    default_conversion: Optional[DefaultConversion] = None,
+    exclude_defaults: Optional[bool] = None,
+    exclude_none: Optional[bool] = None,
+    exclude_unset: Optional[bool] = None,
     fall_back_on_any: bool = True,
-    no_copy: bool = None,
-    pass_through: PassThroughOptions = None,
+    no_copy: Optional[bool] = None,
+    pass_through: Optional[PassThroughOptions] = None,
 ) -> Any:
     ...
 
@@ -640,17 +640,17 @@ def serialize(
     type: AnyType = Any,
     obj: Any = NO_OBJ,
     *,
-    additional_properties: bool = None,
-    aliaser: Aliaser = None,
-    check_type: bool = None,
-    conversion: AnyConversion = None,
-    default_conversion: DefaultConversion = None,
-    exclude_defaults: bool = None,
-    exclude_none: bool = None,
-    exclude_unset: bool = None,
-    fall_back_on_any: bool = None,
-    no_copy: bool = None,
-    pass_through: PassThroughOptions = None,
+    additional_properties: Optional[bool] = None,
+    aliaser: Optional[Aliaser] = None,
+    check_type: Optional[bool] = None,
+    conversion: Optional[AnyConversion] = None,
+    default_conversion: Optional[DefaultConversion] = None,
+    exclude_defaults: Optional[bool] = None,
+    exclude_none: Optional[bool] = None,
+    exclude_unset: Optional[bool] = None,
+    fall_back_on_any: Optional[bool] = None,
+    no_copy: Optional[bool] = None,
+    pass_through: Optional[PassThroughOptions] = None,
 ) -> Any:
     # Handle overloaded signature without type
     if obj is NO_OBJ:
@@ -675,12 +675,12 @@ def serialize(
 
 def serialization_default(
     *,
-    additional_properties: bool = None,
-    aliaser: Aliaser = None,
-    default_conversion: DefaultConversion = None,
-    exclude_defaults: bool = None,
-    exclude_none: bool = None,
-    exclude_unset: bool = None,
+    additional_properties: Optional[bool] = None,
+    aliaser: Optional[Aliaser] = None,
+    default_conversion: Optional[DefaultConversion] = None,
+    exclude_defaults: Optional[bool] = None,
+    exclude_none: Optional[bool] = None,
+    exclude_unset: Optional[bool] = None,
 ) -> Callable[[Any], Any]:
     from apischema import settings
 
