@@ -230,10 +230,13 @@ def replace_builtins(tp: AnyType) -> AnyType:
     if origin in COLLECTION_TYPES:
         if issubclass(origin, collections.abc.Set):
             replacement = SET_ORIGIN
-        elif issubclass(origin, tuple) and (len(args) < 2 or args[1] is not ...):
-            replacement = TUPLE_ORIGIN
-        else:
+        elif not issubclass(origin, tuple):
             replacement = LIST_ORIGIN
+        elif len(args) == 2 and args[1] is ...:
+            args = args[:1]
+            replacement = LIST_ORIGIN
+        else:
+            replacement = TUPLE_ORIGIN
     elif origin in MAPPING_TYPES:
         replacement = DICT_ORIGIN
     elif is_union(origin):
@@ -292,7 +295,7 @@ def literal_values(values: Sequence[Any]) -> Sequence[Any]:
 awaitable_origin = get_origin(Awaitable[Any])
 
 
-def is_async(func: Callable, types: Mapping[str, AnyType] = None) -> bool:
+def is_async(func: Callable, types: Optional[Mapping[str, AnyType]] = None) -> bool:
     wrapped_func = func
     while hasattr(wrapped_func, "__wrapped__"):
         wrapped_func = wrapped_func.__wrapped__  # type: ignore
